==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/




define("_PREVIOUS","W@");
define("_NEXT","U@");

define("_SEARCHRESULTS","jMG");
define("_PAGE","");
define("_RETURNTO","^");
define("_DEACTIVATE","");
define("_ACTIVATE","");
define("_ENCYCLOPEDIA","ʬ/ذ");
define("_NOCONTENTFORLETTER","Sorry, there isn't any content for the letter");
define("_ENCYSELECTLETTER","ХѩUCܭndߪ:");
define("_COPYRIGHT","Copyright &copy; by $sitename. All Right Reserved.");
define("_YOURADMINENCY","zO޲z̡AoӦʬѩ|}!");
define("_ENCYNOTACTIVE","藍_AثeoӦʬѩ|}.");
define("_AVAILABLEENCYLIST","ثeʬѦC");
define("_YOURADMININACTIVELIST","zO޲z̡GUOҰʪʬѦC:");
define("_NORESULTSTEXT","No Results in Term's Text...");
define("_NORESULTSTITLE","No Results in Term's Title...");
define("_SEARCHRESULTSFOR","jMG:");
define("_SEARCHNOTCOMPLETE","jMﶵSAЦAդ@.");
define("_RESULTSINTERMTITLE","Results in the term's title:");
define("_RESULTSINTERMTEXT","Results in the term's text:");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-chinese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/




define("_PREVIOUS","W@");
define("_NEXT","U@");

define("_SEARCHRESULTS","jMG");
define("_PAGE","");
define("_RETURNTO","^");
define("_DEACTIVATE","");
define("_ACTIVATE","");
define("_ENCYCLOPEDIA","ʬ/ذ");
define("_NOCONTENTFORLETTER","Sorry, there isn't any content for the letter");
define("_ENCYSELECTLETTER","ХѩUCܭndߪ:");
define("_COPYRIGHT","Copyright &copy; by $sitename. All Right Reserved.");
define("_YOURADMINENCY","zO޲z̡AoӦʬѩ|}!");
define("_ENCYNOTACTIVE","藍_AثeoӦʬѩ|}.");
define("_AVAILABLEENCYLIST","ثeʬѦC");
define("_YOURADMININACTIVELIST","zO޲z̡GUOҰʪʬѦC:");
define("_NORESULTSTEXT","No Results in Term's Text...");
define("_NORESULTSTITLE","No Results in Term's Title...");
define("_SEARCHRESULTSFOR","jMG:");
define("_SEARCHNOTCOMPLETE","jMﶵSAЦAդ@.");
define("_RESULTSINTERMTITLE","Results in the term's title:");
define("_RESULTSINTERMTEXT","Results in the term's text:");


?>
